# Wargame: Red Dragon Tools

This is a collection of tools for modding Wargame: Red Dragon, a game from Eugen Systems.
These tools use the parsers found in wgrd-cons-parsers and usually
work on the XML generated from them or just directly use them in Python.

See https://wgrd-cons-tools.readthedocs.io on how to use them.
